# Generated by roxygen2: do not edit by hand

S3method(AIC,beezdemand_hurdle)
S3method(BIC,beezdemand_hurdle)
S3method(anova,beezdemand_hurdle)
S3method(anova,beezdemand_nlme)
S3method(augment,beezdemand_fixed)
S3method(augment,beezdemand_hurdle)
S3method(augment,beezdemand_nlme)
S3method(calc_group_metrics,beezdemand_hurdle)
S3method(calculate_amplitude_persistence,beezdemand_fixed)
S3method(calculate_amplitude_persistence,beezdemand_hurdle)
S3method(calculate_amplitude_persistence,beezdemand_nlme)
S3method(calculate_amplitude_persistence,default)
S3method(check_demand_model,beezdemand_fixed)
S3method(check_demand_model,beezdemand_hurdle)
S3method(check_demand_model,beezdemand_nlme)
S3method(coef,beezdemand_fixed)
S3method(coef,beezdemand_hurdle)
S3method(coef,beezdemand_nlme)
S3method(coef,cp_model_lm)
S3method(coef,cp_model_lmer)
S3method(coef,cp_model_nls)
S3method(confint,beezdemand_fixed)
S3method(confint,beezdemand_hurdle)
S3method(confint,beezdemand_nlme)
S3method(confint,cp_model_nls)
S3method(fixef,beezdemand_nlme)
S3method(fixef,cp_model_lmer)
S3method(get_subject_pars,beezdemand_hurdle)
S3method(glance,beezdemand_fixed)
S3method(glance,beezdemand_hurdle)
S3method(glance,beezdemand_nlme)
S3method(glance,beezdemand_systematicity)
S3method(glance,cp_model_lm)
S3method(glance,cp_model_lmer)
S3method(glance,cp_model_nls)
S3method(logLik,beezdemand_hurdle)
S3method(plot,beezdemand_descriptive)
S3method(plot,beezdemand_empirical)
S3method(plot,beezdemand_fixed)
S3method(plot,beezdemand_hurdle)
S3method(plot,beezdemand_nlme)
S3method(plot,cp_model_lm)
S3method(plot,cp_model_lmer)
S3method(plot,cp_model_nls)
S3method(plot_qq,beezdemand_hurdle)
S3method(plot_qq,beezdemand_nlme)
S3method(predict,beezdemand_fixed)
S3method(predict,beezdemand_hurdle)
S3method(predict,beezdemand_nlme)
S3method(predict,cp_model_lm)
S3method(predict,cp_model_lmer)
S3method(predict,cp_model_nls)
S3method(print,anova.beezdemand_hurdle)
S3method(print,beezdemand_comparison)
S3method(print,beezdemand_descriptive)
S3method(print,beezdemand_diagnostics)
S3method(print,beezdemand_empirical)
S3method(print,beezdemand_fixed)
S3method(print,beezdemand_hurdle)
S3method(print,beezdemand_model_comparison)
S3method(print,beezdemand_nlme)
S3method(print,beezdemand_summary)
S3method(print,beezdemand_systematicity)
S3method(print,cp_posthoc)
S3method(print,summary.beezdemand_fixed)
S3method(print,summary.beezdemand_hurdle)
S3method(print,summary.beezdemand_nlme)
S3method(print,summary.beezdemand_systematicity)
S3method(print,summary.cp_model_lm)
S3method(print,summary.cp_model_lmer)
S3method(print,summary.cp_model_nls)
S3method(print,summary.cp_unsystematic)
S3method(ranef,beezdemand_nlme)
S3method(ranef,cp_model_lmer)
S3method(summary,beezdemand_descriptive)
S3method(summary,beezdemand_empirical)
S3method(summary,beezdemand_fixed)
S3method(summary,beezdemand_hurdle)
S3method(summary,beezdemand_nlme)
S3method(summary,beezdemand_systematicity)
S3method(summary,cp_model_lm)
S3method(summary,cp_model_lmer)
S3method(summary,cp_model_nls)
S3method(summary,cp_unsystematic)
S3method(tidy,beezdemand_fixed)
S3method(tidy,beezdemand_hurdle)
S3method(tidy,beezdemand_nlme)
S3method(tidy,beezdemand_systematicity)
S3method(tidy,cp_model_lm)
S3method(tidy,cp_model_lmer)
S3method(tidy,cp_model_nls)
export(ChangeData)
export(CheckCols)
export(CheckUnsystematic)
export(ExtraF)
export(FitCurves)
export(FitMeanCurves)
export(GetAnalyticPmax)
export(GetAnalyticPmaxFallback)
export(GetDescriptives)
export(GetEmpirical)
export(GetK)
export(GetSharedK)
export(GetValsForSim)
export(PlotCurve)
export(PlotCurves)
export(RecodeOutliers)
export(ReplaceZeros)
export(SimulateDemand)
export(augment)
export(beezdemand_calc_pmax_omax)
export(beezdemand_calc_pmax_omax_vec)
export(calc_group_metrics)
export(calc_observed_pmax_omax)
export(calc_omax_pmax)
export(calculate_amplitude_persistence)
export(check_demand_model)
export(check_systematic_cp)
export(check_systematic_demand)
export(check_unsystematic_cp)
export(compare_hurdle_models)
export(compare_models)
export(cp_posthoc_intercepts)
export(cp_posthoc_slopes)
export(extract_coefficients)
export(fit_cp_linear)
export(fit_cp_linear.default)
export(fit_cp_linear.mixed)
export(fit_cp_nls)
export(fit_demand_fixed)
export(fit_demand_hurdle)
export(fit_demand_mixed)
export(get_demand_comparisons)
export(get_demand_param_emms)
export(get_demand_param_trends)
export(get_descriptive_summary)
export(get_empirical_measures)
export(get_hurdle_param_summary)
export(get_individual_coefficients)
export(get_k)
export(get_observed_demand_param_emms)
export(get_subject_pars)
export(glance)
export(lambertW)
export(ll4)
export(ll4_inv)
export(palette_beezdemand)
export(pivot_demand_data)
export(plot_qq)
export(plot_residuals)
export(plot_subject)
export(print_mc_summary)
export(pseudo_ll4_trans)
export(run_hurdle_monte_carlo)
export(scale_color_beezdemand)
export(scale_fill_beezdemand)
export(scale_ll4)
export(simulate_hurdle_data)
export(theme_apa)
export(theme_beezdemand)
export(tidy)
import(ggplot2)
import(grDevices)
import(graphics)
import(stats)
importFrom(TMB,MakeADFun)
importFrom(TMB,sdreport)
importFrom(broom,augment)
importFrom(broom,glance)
importFrom(broom,tidy)
importFrom(dplyr,across)
importFrom(dplyr,all_of)
importFrom(dplyr,any_of)
importFrom(dplyr,arrange)
importFrom(dplyr,bind_rows)
importFrom(dplyr,distinct)
importFrom(dplyr,everything)
importFrom(dplyr,full_join)
importFrom(dplyr,group_by)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,n)
importFrom(dplyr,rename)
importFrom(dplyr,select)
importFrom(dplyr,semi_join)
importFrom(dplyr,summarise)
importFrom(emmeans,contrast)
importFrom(emmeans,emmeans)
importFrom(emmeans,emtrends)
importFrom(emmeans,ref_grid)
importFrom(ggplot2,aes)
importFrom(ggplot2,facet_wrap)
importFrom(ggplot2,geom_histogram)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_qq)
importFrom(ggplot2,geom_qq_line)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_y_log10)
importFrom(ggplot2,theme_minimal)
importFrom(lifecycle,deprecate_soft)
importFrom(lifecycle,deprecate_warn)
importFrom(lifecycle,deprecated)
importFrom(lifecycle,is_present)
importFrom(lme4,VarCorr)
importFrom(lme4,fixef)
importFrom(lme4,lmer)
importFrom(lme4,ranef)
importFrom(minpack.lm,nls.lm.control)
importFrom(minpack.lm,nlsLM)
importFrom(nlme,fixef)
importFrom(nlme,nlme)
importFrom(nlme,nlmeControl)
importFrom(nlme,pdDiag)
importFrom(nls.multstart,nls_multstart)
importFrom(nlsr,wrapnlsr)
importFrom(nlstools,confint2)
importFrom(performance,r2_nakagawa)
importFrom(rlang,"!!!")
importFrom(rlang,"!!")
importFrom(rlang,.data)
importFrom(rlang,`:=`)
importFrom(rlang,expr)
importFrom(rlang,sym)
importFrom(rlang,syms)
importFrom(scales,identity_trans)
importFrom(scales,log10_trans)
importFrom(scales,pseudo_log_trans)
importFrom(stats,AIC)
importFrom(stats,BIC)
importFrom(stats,as.formula)
importFrom(stats,coef)
importFrom(stats,median)
importFrom(stats,model.matrix)
importFrom(stats,na.omit)
importFrom(stats,nlminb)
importFrom(stats,pchisq)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,rbinom)
importFrom(stats,residuals)
importFrom(stats,rnorm)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,terms)
importFrom(stats,update)
importFrom(tibble,as_tibble)
importFrom(tibble,rownames_to_column)
importFrom(tidyr,crossing)
importFrom(tidyr,expand_grid)
importFrom(tidyr,pivot_longer)
importFrom(tidyr,pivot_wider)
importFrom(utils,head)
importFrom(utils,modifyList)
useDynLib(beezdemand, .registration = TRUE)
